# rspec/airborne/spaceborne based API tests

## Setting up new API tests for a service

```ch new service 'queuemr'```
 will create a new ruby service with an apitest directory structure for you. You will need your service up and running in some environment so that introspection can be performed. Once you have your service stood up in that environment(XXX), you should be able to run the following (from the new service's apitest directory):

```ruby
gem install bundler
bundle install
TEST_ENV=XXX rspec spec/service_template_spec.rb
```
This will test that you can get an auth token from local-auth, and that your service can support introspection.

You may need to make some manual adjustments to the `lib/cht_apitest_queuemr/service.rb` file if your staging and prod deployments use a namespace other than queuemr. Change the `default_namespace` value to the namespace used. In addition, if the service deployed in that namespace differs from queuemr, you should modify the `service_name` value.

It is highly advised that you save the version of your service's schema (introspection response json), to enable detection of schema changes (indicating tests should be updated). To do this (from your apitest directory):

```sh
mkdir supported_schemas
TEST_ENV=XXX bundle exec rspec --tag save_schema
```

Once this works, you will probably want to get support for request formatters, response checkers and shortcuts. This is done by introspection on your service, and will automatically change some files to support your service. Run the following:

```ruby
TEST_ENV=XXX bundle exec bin/add_service
```
Some manual adjustment of the lib/helpers/formatter.yml file may be required if your service's schema has responses that sometimes aren't present or return null. You can allow this by appending ```'_or_null'``` to the value specified. For the above example, the clientMutationId returns null unless your request specifies one, so modify the line to contain:

```:clientMutationId: :string_or_null```

Another helper that can get you going with apitests quickly is by running:

```ruby
TEST_ENV=XXX bundle exec bin/add_feature -f all
```
This will take any mutation/query that your service supports and attempting to build a spec for that feature that contains a positive and negative test case. The generated specs will still need adjustment to supply legal input values (which introspection can't really give guidance on).

You will probably also want some performance tests for your service. The following command gets you most of the way to having a simulation which will run each user through a sequence of the api calls that your service supports:

```ruby
TEST_ENV=XXX bundle exec bin/add_gatling
```
The generated simulation will still need adjustment to supply legal input values (which introspection can't really give guidance on).

##Cleanup
Once you are satisfied with these steps, feel free to remove this README and the bin directory from your repo.