# frozen_string_literal: true

require 'cht-chaphql'
require 'cht-chaphql/graphql_formatters'

QUEUEMR_FMTRS =
  YAML.load_file(File.join(__dir__, '../helpers/formatters.yml'))

# module for queuemr
module ChtApitestQueuemr
  include Chaphql
  include Chaphql::GraphQLHelpers

  # module for your shortcuts
  module QueuemrHelpers
    # insertion point for shortcuts

    def create_job(args = {})
      args[:service] = QueuemrService.new
      sym = first_no_cap(camelize('create_job')).to_sym
      headers = apitest_headers(
        args.merge(with_auth: true,
        auth_service: LocalAuthService.new))
      data = format_request(sym, args)
      variables = { input: { cloudType: args[:cloudType], customerId: args[:customerId], deDuplicationId: args[:deDuplicationId], jobType: args[:jobType], month: args[:month], payloadS3Path: args[:payloadS3Path], priority: args[:priority], size: args[:size] } }
      graphql url(args), data, variables, headers, args
      expect_success_graphql
      check(sym, args)
      json_body[:data][sym]
    end

    def create_job_type(args = {})
      args[:service] = QueuemrService.new
      sym = first_no_cap(camelize('create_job_type')).to_sym
      headers = apitest_headers(
        args.merge(with_auth: true,
        auth_service: LocalAuthService.new))
      data = format_request(sym, args)
      variables = { input: args[:input] }
      graphql url(args), data, variables, headers, args
      expect_success_graphql
      check(sym, args)
      json_body[:data][sym]
    end

    def update_job_type(args = {})
      args[:service] = QueuemrService.new
      sym = first_no_cap(camelize('update_job_type')).to_sym
      headers = apitest_headers(
        args.merge(with_auth: true,
        auth_service: LocalAuthService.new))
      data = format_request(sym, args)
      variables = { input: args[:input] }
      graphql url(args), data, variables, headers, args
      expect_success_graphql
      check(sym, args)
      json_body[:data][sym]
    end

    def create_emr_cluster(args = {})
      args[:service] = QueuemrService.new
      sym = first_no_cap(camelize('create_emr_cluster')).to_sym
      headers = apitest_headers(
        args.merge(with_auth: true,
        auth_service: LocalAuthService.new))
      data = format_request(sym, args)
      variables = { input: { emrClusterId: args[:emrClusterId], jobSize: args[:jobSize], jobType: args[:jobType], livyEnabled: args[:livyEnabled], livySessionNumExecutors: args[:livySessionNumExecutors], livyUrl: args[:livyUrl], maxActiveJobs: args[:maxActiveJobs], sessionCount: args[:sessionCount], status: args[:status] } }
      graphql url(args), data, variables, headers, args
      expect_success_graphql
      check(sym, args)
      json_body[:data][sym]
    end

    def update_emr_cluster(args = {})
      args[:service] = QueuemrService.new
      sym = first_no_cap(camelize('update_emr_cluster')).to_sym
      headers = apitest_headers(
        args.merge(with_auth: true,
        auth_service: LocalAuthService.new))
      data = format_request(sym, args)
      variables = { input: { emrClusterId: args[:emrClusterId], jobSize: args[:jobSize], jobType: args[:jobType], maxActiveJobs: args[:maxActiveJobs], sessionCount: args[:sessionCount], status: args[:status] } }
      graphql url(args), data, variables, headers, args
      expect_success_graphql
      check(sym, args)
      json_body[:data][sym]
    end

    def delete_cluster(args = {})
      args[:service] = QueuemrService.new
      sym = first_no_cap(camelize('delete_cluster')).to_sym
      headers = apitest_headers(
        args.merge(with_auth: true,
        auth_service: LocalAuthService.new))
      data = format_request(sym, args)
      variables = { clusterId: args[:clusterId] }
      graphql url(args), data, variables, headers, args
      expect_success_graphql
      check(sym, args)
      json_body[:data][sym]
    end

    def get_job(args = {})
      args[:service] = QueuemrService.new
      sym = first_no_cap(camelize('get_job')).to_sym
      headers = apitest_headers(
        args.merge(with_auth: true,
        auth_service: LocalAuthService.new))
      data = format_request(sym, args)
      variables = { id: args[:id] }
      graphql url(args), data, variables, headers, args
      expect_success_graphql
      check(sym, args)
      json_body[:data][sym]
    end

    def get_job_type(args = {})
      args[:service] = QueuemrService.new
      sym = first_no_cap(camelize('get_job_type')).to_sym
      headers = apitest_headers(
        args.merge(with_auth: true,
        auth_service: LocalAuthService.new))
      data = format_request(sym, args)
      variables = { name: args[:name] }
      graphql url(args), data, variables, headers, args
      expect_success_graphql
      check(sym, args)
      json_body[:data][sym]
    end

    def get_all_job_types(args = {})
      args[:service] = QueuemrService.new
      sym = first_no_cap(camelize('get_all_job_types')).to_sym
      headers = apitest_headers(
        args.merge(with_auth: true,
        auth_service: LocalAuthService.new))
      data = format_request(sym, args)
      variables = {  }
      graphql url(args), data, variables, headers, args
      expect_success_graphql
      check(sym, args)
      json_body[:data][sym]
    end

    def get_cluster(args = {})
      args[:service] = QueuemrService.new
      sym = first_no_cap(camelize('get_cluster')).to_sym
      headers = apitest_headers(
        args.merge(with_auth: true,
        auth_service: LocalAuthService.new))
      data = format_request(sym, args)
      variables = { clusterId: args[:clusterId] }
      graphql url(args), data, variables, headers, args
      expect_success_graphql
      check(sym, args)
      json_body[:data][sym]
    end

    def get_all_clusters(args = {})
      args[:service] = QueuemrService.new
      sym = first_no_cap(camelize('get_all_clusters')).to_sym
      headers = apitest_headers(
        args.merge(with_auth: true,
        auth_service: LocalAuthService.new))
      data = format_request(sym, args)
      variables = {  }
      graphql url(args), data, variables, headers, args
      expect_success_graphql
      check(sym, args)
      json_body[:data][sym]
    end

    def get_all_sessions(args = {})
      args[:service] = QueuemrService.new
      sym = first_no_cap(camelize('get_all_sessions')).to_sym
      headers = apitest_headers(
        args.merge(with_auth: true,
        auth_service: LocalAuthService.new))
      data = format_request(sym, args)
      variables = { jobSize: args[:jobSize], jobType: args[:jobType], status: args[:status] }
      graphql url(args), data, variables, headers, args
      expect_success_graphql
      check(sym, args)
      json_body[:data][sym]
    end

    # end of shortcut insertion
  end

  # class for your service
  class QueuemrService < ChtNgService
    include RSpec::Matchers

    QUEUEMR_DEFAULTS = {
      name: 'Queuemr',
      default_namespace: 'queuemr',
      service_name: 'queuemr',
      pr_parent: 'queuemr',
      formatters: QUEUEMR_FMTRS['formatters'],
      checkers: QUEUEMR_FMTRS['checkers']
    }.freeze
    def initialize(args = {})
      super(args.merge(QUEUEMR_DEFAULTS))
    end
  end

  # class for api-proxy support of queuemr service
  class ApiProxyQueuemr < ChtNgService
    include RSpec::Matchers

    API_PROXY_DEFAULTS = {
      name: 'ApiProxyQueuemr',
      default_namespace: 'api-proxy',
      service_name: 'api-proxy',
      pr_parent: 'api-proxy',
      formatters: QUEUEMR_FMTRS['formatters'],
      checkers: QUEUEMR_FMTRS['checkers']
    }.freeze
    def initialize(args = {})
      super(args.merge(API_PROXY_DEFAULTS))
    end
  end
end
